##  Prioritize Risks by Business Criticality
From the report’s Settings, cluster the applications by their Business Criticality. This easily helps you distinguish which applications pose the most immediate and potentially business-disrupting threat. Understanding this helps prioritize which obsolescence risks to address first.
You can use the time-slider to see what applications and their underlying IT components change lifecycle phase in the next fiscal year and already also require attention. This aids in budget planning purposes. In the following example, applications “Cost Modeling” and “Contract Management” not only have theUnaddressed Risk status but are also facing phase out risks by the end of 2025.
Applications Clustered by Business Criticality in Application Landscape Report
![Applications Clustered by Business Criticality in Application Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275657d37a44101488c0d250440bf106_LowRes.png)
**Tip**
  * Focus on end of-life risks first before addressing IT components that are in a phase-out state.
  * Use business criticality, lifecycle state, successor, business context, time horizon, cost to prioritize applications for evaluation. This targeted approach allows for manageable goals, allowing for quick wins and gaining additional stakeholder buy-in and support for your initiatives.
  * Use tags or create a custom field to capture the priority of each identified risk. For guidance on when to use tags versus custom fields, see [Using Tags and Custom Fields](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to effectively use tags and custom fields in SAP LeanIX.").


Within the report, select the application to open the side panel and find out which IT components support the application and what their obsolescence risk statuses are. These insights equip you to reach out to the application owner and define a transformation path for addressing IT components with the Unaddressed Risk status.
![Obsolescence Risk Details Accessed in the Right Side Panel](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757c7c17a441014a15f9bab86f52f78_LowRes.png)
Obsolescence Risk Details Accessed in the Right Side Panel
